@@ -8,8 +8,7 @@ from __future__ import absolute_import, unicode_literals
 import unittest
 
 from django.core.management import call_command
-
-from nine.versions import DJANGO_GTE_1_10
+from django.urls import reverse
 
 import pytest
 
@@ -25,11 +24,6 @@ from ..versions import (
 from .base import BaseRestFrameworkTestCase
 from .data_mixins import AddressesMixin
 
-if DJANGO_GTE_1_10:
-    from django.urls import reverse
-else:
-    from django.core.urlresolvers import reverse
-
 __title__ = 'django_elasticsearch_dsl_drf.tests.test_suggesters'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = '2017-2020 Artur Barseghyan'
